@@ -1,5 +1,5 @@
 ﻿/*
-Copyright (c) 2003-2010, CKSource - Frederico Knabben. All rights reserved.
+Copyright (c) 2003-2012, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.html or http://ckeditor.com/license
 */
 
@@ -14,7 +14,7 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 */
 
 /**
- * Constains the dictionary of language entries.
+ * Contains the dictionary of language entries.
  * @namespace
  */
 CKEDITOR.lang['he'] =
@@ -31,11 +31,11 @@ CKEDITOR.lang['he'] =
 	 * Screenreader titles. Please note that screenreaders are not always capable
 	 * of reading non-English words. So be careful while translating it.
 	 */
-	editorTitle : 'Rich text editor, %1, press ALT 0 for help.', // MISSING
+	editorTitle : 'עורך טקסט עשיר, %1, לחץ אלט (ALT) + 0 לעזרה.',
 
 	// ARIA descriptions.
-	toolbar	: 'Toolbar', // MISSING
-	editor	: 'Rich Text Editor', // MISSING
+	toolbars	: 'סרגלי כלים של העורך',
+	editor		: 'עורך טקסט עשיר',
 
 	// Toolbar buttons without dialogs.
 	source			: 'מקור',
@@ -56,6 +56,7 @@ CKEDITOR.lang['he'] =
 	superscript		: 'כתיב עליון',
 	horizontalrule	: 'הוספת קו אופקי',
 	pagebreak		: 'הוספת שבירת דף',
+	pagebreakAlt		: 'שבירת דף',
 	unlink			: 'הסרת הקישור',
 	undo			: 'ביטול צעד אחרון',
 	redo			: 'חזרה על צעד אחרון',
@@ -92,35 +93,61 @@ CKEDITOR.lang['he'] =
 		cssStyle		: 'סגנון',
 		ok				: 'אישור',
 		cancel			: 'ביטול',
-		close			: 'Close', // MISSING
-		preview			: 'Preview', // MISSING
+		close			: 'סגירה',
+		preview			: 'תצוגה מקדימה',
 		generalTab		: 'כללי',
 		advancedTab		: 'אפשרויות מתקדמות',
 		validateNumberFailed : 'הערך חייב להיות מספרי.',
 		confirmNewPage	: 'כל השינויים שלא נשמרו יאבדו. האם להעלות דף חדש?',
 		confirmCancel	: 'חלק מהאפשרויות שונו, האם לסגור את הדיאלוג?',
-		options			: 'Options', // MISSING
-		target			: 'Target', // MISSING
-		targetNew		: 'New Window (_blank)', // MISSING
-		targetTop		: 'Topmost Window (_top)', // MISSING
-		targetSelf		: 'Same Window (_self)', // MISSING
-		targetParent	: 'Parent Window (_parent)', // MISSING
+		options			: 'אפשרויות',
+		target			: 'מטרה',
+		targetNew		: 'חלון חדש (_blank)',
+		targetTop		: 'החלון העליון ביותר (_top)',
+		targetSelf		: 'אותו חלון (_self)',
+		targetParent	: 'חלון האב (_parent)',
+		langDirLTR		: 'שמאל לימין (LTR)',
+		langDirRTL		: 'ימין לשמאל (RTL)',
+		styles			: 'סגנון',
+		cssClasses		: 'מחלקות גליונות סגנון',
+		width			: 'רוחב',
+		height			: 'גובה',
+		align			: 'יישור',
+		alignLeft		: 'לשמאל',
+		alignRight		: 'לימין',
+		alignCenter		: 'מרכז',
+		alignTop		: 'למעלה',
+		alignMiddle		: 'לאמצע',
+		alignBottom		: 'לתחתית',
+		invalidHeight	: 'הגובה חייב להיות מספר.',
+		invalidWidth	: 'הרוחב חייב להיות מספר.',
+		invalidCssLength	: 'הערך שצוין לשדה "%1" חייב להיות מספר חיובי עם או ללא יחידת מידה חוקית של CSS (px, %, in, cm, mm, em, ex, pt, או pc).',
+		invalidHtmlLength	: 'הערך שצוין לשדה "%1" חייב להיות מספר חיובי עם או ללא יחידת מידה חוקית של HTML (px או %).',
+		invalidInlineStyle	: 'הערך שצויין לשדה הסגנון חייב להכיל זוג ערכים אחד או יותר בפורמט "שם : ערך", מופרדים על ידי נקודה-פסיק.',
+		cssLengthTooltip	: 'יש להכניס מספר המייצג פיקסלים או מספר עם יחידת גליונות סגנון תקינה (px, %, in, cm, mm, em, ex, pt, or pc).',
 
 		// Put the voice-only part of the label in the span.
 		unavailable		: '%1<span class="cke_accessibility">, לא זמין</span>'
 	},
 
+	contextmenu :
+	{
+		options : 'אפשרויות תפריט ההקשר'
+	},
+
 	// Special char dialog.
 	specialChar		:
 	{
 		toolbar		: 'הוספת תו מיוחד',
-		title		: 'בחירת תו מיוחד'
+		title		: 'בחירת תו מיוחד',
+		options : 'אפשרויות תווים מיוחדים'
 	},
 
 	// Link dialog.
 	link :
 	{
 		toolbar		: 'הוספת/עריכת קישור',
+		other 		: '<אחר>',
 		menu		: 'מאפייני קישור',
 		title		: 'קישור',
 		info		: 'מידע על הקישור',
@@ -128,7 +155,7 @@ CKEDITOR.lang['he'] =
 		upload		: 'העלאה',
 		advanced	: 'אפשרויות מתקדמות',
 		type		: 'סוג קישור',
-		toUrl		: 'URL', // MISSING
+		toUrl		: 'כתובת (URL)',
 		toAnchor	: 'עוגן בעמוד זה',
 		toEmail		: 'דוא"ל',
 		targetFrame		: '<מסגרת>',
@@ -144,9 +171,7 @@ CKEDITOR.lang['he'] =
 		popupFullScreen	: 'מסך מלא (IE)',
 		popupScrollBars	: 'ניתן לגלילה',
 		popupDependent	: 'תלוי (Netscape)',
-		popupWidth		: 'רוחב',
 		popupLeft		: 'מיקום צד שמאל',
-		popupHeight		: 'גובה',
 		popupTop		: 'מיקום צד עליון',
 		id				: 'זיהוי (ID)',
 		langDir			: 'כיוון שפה',
@@ -154,18 +179,19 @@ CKEDITOR.lang['he'] =
 		langDirRTL		: 'ימין לשמאל (RTL)',
 		acccessKey		: 'מקש גישה',
 		name			: 'שם',
-		langCode		: 'קוד שפה',
-		tabIndex		: 'מספר טאב',
-		advisoryTitle	: 'כותרת מוצעת',
+		langCode			: 'קוד שפה',
+		tabIndex			: 'מספר טאב',
+		advisoryTitle		: 'כותרת מוצעת',
 		advisoryContentType	: 'Content Type מוצע',
 		cssClasses		: 'גיליונות עיצוב קבוצות',
 		charset			: 'קידוד המשאב המקושר',
 		styles			: 'סגנון',
-		selectAnchor	: 'בחירת עוגן',
+		rel			: 'קשר גומלין',
+		selectAnchor		: 'בחירת עוגן',
 		anchorName		: 'עפ"י שם העוגן',
-		anchorId		: 'עפ"י זיהוי (ID) האלמנט',
-		emailAddress	: 'כתובת הדוא"ל',
-		emailSubject	: 'נושא ההודעה',
+		anchorId			: 'עפ"י זיהוי (ID) האלמנט',
+		emailAddress		: 'כתובת הדוא"ל',
+		emailSubject		: 'נושא ההודעה',
 		emailBody		: 'גוף ההודעה',
 		noAnchors		: '(אין עוגנים זמינים בדף)',
 		noUrl			: 'יש להקליד את כתובת הקישור (URL)',
@@ -179,7 +205,32 @@ CKEDITOR.lang['he'] =
 		menu		: 'מאפייני נקודת עיגון',
 		title		: 'מאפייני נקודת עיגון',
 		name		: 'שם לנקודת עיגון',
-		errorName	: 'יש להקליד שם לנקודת עיגון'
+		errorName	: 'יש להקליד שם לנקודת עיגון',
+		remove		: 'מחיקת נקודת עיגון'
+	},
+
+	// List style dialog
+	list:
+	{
+		numberedTitle		: 'תכונות רשימה ממוספרת',
+		bulletedTitle		: 'תכונות רשימת תבליטים',
+		type				: 'סוג',
+		start				: 'תחילת מספור',
+		validateStartNumber				:'שדה תחילת המספור חייב להכיל מספר שלם.',
+		circle				: 'עיגול ריק',
+		disc				: 'עיגול מלא',
+		square				: 'ריבוע',
+		none				: 'ללא',
+		notset				: '<לא נקבע>',
+		armenian			: 'ספרות ארמניות',
+		georgian			: 'ספרות גיאורגיות (an, ban, gan וכו\')',
+		lowerRoman			: 'ספירה רומית באותיות קטנות (i, ii, iii, iv, v וכו\')',
+		upperRoman			: 'ספירה רומיות באותיות גדולות (I, II, III, IV, V וכו\')',
+		lowerAlpha			: 'אותיות אנגליות קטנות (a, b, c, d, e וכו\')',
+		upperAlpha			: 'אותיות אנגליות גדולות (A, B, C, D, E וכו\')',
+		lowerGreek			: 'אותיות יווניות קטנות (alpha, beta, gamma וכו\')',
+		decimal				: 'ספרות (1, 2, 3 וכו\')',
+		decimalLeadingZero	: 'ספרות עם 0 בהתחלה (01, 02, 03 וכו\')'
 	},
 
 	// Find And Replace Dialog
@@ -191,6 +242,7 @@ CKEDITOR.lang['he'] =
 		findWhat			: 'חיפוש מחרוזת:',
 		replaceWith			: 'החלפה במחרוזת:',
 		notFoundMsg			: 'הטקסט המבוקש לא נמצא.',
+		findOptions			: 'אפשרויות חיפוש',
 		matchCase			: 'הבחנה בין אותיות רשיות לקטנות (Case)',
 		matchWord			: 'התאמה למילה המלאה',
 		matchCyclic			: 'התאמה מחזורית',
@@ -208,15 +260,9 @@ CKEDITOR.lang['he'] =
 		rows		: 'שורות',
 		columns		: 'עמודות',
 		border		: 'גודל מסגרת',
-		align		: 'יישור',
-		alignLeft	: 'שמאל',
-		alignCenter	: 'מרכז',
-		alignRight	: 'ימין',
-		width		: 'רוחב',
 		widthPx		: 'פיקסלים',
 		widthPc		: 'אחוז',
-		widthUnit	: 'width unit', // MISSING
-		height		: 'גובה',
+		widthUnit	: 'יחידת רוחב',
 		cellSpace	: 'מרווח תא',
 		cellPad		: 'ריפוד תא',
 		caption		: 'כיתוב',
@@ -229,10 +275,10 @@ CKEDITOR.lang['he'] =
 		invalidRows		: 'שדה מספר השורות חייב להיות מספר גדול מ 0.',
 		invalidCols		: 'שדה מספר העמודות חייב להיות מספר גדול מ 0.',
 		invalidBorder	: 'שדה גודל המסגרת חייב להיות מספר.',
-		invalidWidth	: 'שדה רוחב הטבלה חייב להיות רוחב.',
+		invalidWidth	: 'שדה רוחב הטבלה חייב להיות מספר.',
 		invalidHeight	: 'שדה גובה הטבלה חייב להיות מספר.',
-		invalidCellSpacing	: 'שדה ריווח התאים חייב להיות מספר.',
-		invalidCellPadding	: 'שדה ריפוד התאים חייב להיות מספר.',
+		invalidCellSpacing	: 'שדה ריווח התאים חייב להיות מספר חיובי.',
+		invalidCellPadding	: 'שדה ריפוד התאים חייב להיות מספר חיובי.',
 
 		cell :
 		{
@@ -252,9 +298,6 @@ CKEDITOR.lang['he'] =
 			wordWrap		: 'מניעת גלישת שורות',
 			hAlign			: 'יישור אופקי',
 			vAlign			: 'יישור אנכי',
-			alignTop		: 'למעלה',
-			alignMiddle		: 'מרכז',
-			alignBottom		: 'למטה',
 			alignBaseline	: 'שורת בסיס',
 			bgColor			: 'צבע רקע',
 			borderColor		: 'צבע מסגרת',
@@ -375,27 +418,19 @@ CKEDITOR.lang['he'] =
 		btnUpload	: 'שליחה לשרת',
 		upload		: 'העלאה',
 		alt			: 'טקסט חלופי',
-		width		: 'רוחב',
-		height		: 'גובה',
 		lockRatio	: 'נעילת היחס',
-		unlockRatio	: 'Unlock Ratio', // MISSING
 		resetSize	: 'איפוס הגודל',
 		border		: 'מסגרת',
 		hSpace		: 'מרווח אופקי',
 		vSpace		: 'מרווח אנכי',
-		align		: 'יישור',
-		alignLeft	: 'לשמאל',
-		alignRight	: 'לימין',
 		alertUrl	: 'יש להקליד את כתובת התמונה',
 		linkTab		: 'קישור',
 		button2Img	: 'האם להפוך את תמונת הכפתור לתמונה פשוטה?',
 		img2Button	: 'האם להפוך את התמונה לכפתור תמונה?',
 		urlMissing	: 'כתובת התמונה חסרה.',
-		validateWidth	: 'Width must be a whole number.', // MISSING
-		validateHeight	: 'Height must be a whole number.', // MISSING
-		validateBorder	: 'Border must be a whole number.', // MISSING
-		validateHSpace	: 'HSpace must be a whole number.', // MISSING
-		validateVSpace	: 'VSpace must be a whole number.' // MISSING
+		validateBorder	: 'שדה המסגרת חייב להיות מספר שלם.',
+		validateHSpace	: 'שדה המרווח האופקי חייב להיות מספר שלם.',
+		validateVSpace	: 'שדה המרווח האנכי חייב להיות מספר שלם.'
 	},
 
 	// Flash Dialog
@@ -416,16 +451,10 @@ CKEDITOR.lang['he'] =
 		accessAlways	: 'תמיד',
 		accessSameDomain: 'דומיין זהה',
 		accessNever		: 'אף פעם',
-		align			: 'יישור',
-		alignLeft		: 'לשמאל',
 		alignAbsBottom	: 'לתחתית האבסולוטית',
 		alignAbsMiddle	: 'מרכוז אבסולוטי',
 		alignBaseline	: 'לקו התחתית',
-		alignBottom		: 'לתחתית',
-		alignMiddle		: 'לאמצע',
-		alignRight		: 'לימין',
 		alignTextTop	: 'לראש הטקסט',
-		alignTop		: 'למעלה',
 		quality			: 'איכות',
 		qualityBest		: 'מעולה',
 		qualityHigh		: 'גבוהה',
@@ -439,13 +468,9 @@ CKEDITOR.lang['he'] =
 		windowMode		: 'מצב חלון',
 		flashvars		: 'משתנים לפלאש',
 		bgcolor			: 'צבע רקע',
-		width			: 'רוחב',
-		height			: 'גובה',
 		hSpace			: 'מרווח אופקי',
 		vSpace			: 'מרווח אנכי',
 		validateSrc		: 'יש להקליד את כתובת סרטון הפלאש (URL)',
-		validateWidth	: 'הרוחב חייב להיות מספר.',
-		validateHeight	: 'הגובה חייב להיות מספר.',
 		validateHSpace	: 'המרווח האופקי חייב להיות מספר.',
 		validateVSpace	: 'המרווח האנכי חייב להיות מספר.'
 	},
@@ -476,12 +501,13 @@ CKEDITOR.lang['he'] =
 	smiley :
 	{
 		toolbar	: 'סמיילי',
-		title	: 'הוספת סמיילי'
+		title	: 'הוספת סמיילי',
+		options : 'אפשרויות סמיילים'
 	},
 
 	elementsPath :
 	{
-		eleLabel : 'Elements path', // MISSING
+		eleLabel : 'עץ האלמנטים',
 		eleTitle : '%1 אלמנט'
 	},
 
@@ -503,11 +529,11 @@ CKEDITOR.lang['he'] =
 	clipboard :
 	{
 		title		: 'הדבקה',
-		cutError	: 'הגדרות האבטחה בדפדפן שלך לא מאפשרות לעורך לבצע פעולות גזירה אוטומטיות. יש להשתמש במקלדת לשם כך (Ctrl+X).',
-		copyError	: 'הגדרות האבטחה בדפדפן שלך לא מאפשרות לעורך לבצע פעולות העתקה אוטומטיות. יש להשתמש במקלדת לשם כך (Ctrl+C).',
-		pasteMsg	: 'נא להדביק בתוך הקופסה באמצעות (<b>Ctrl+V</b>) וללחוץ על <b>אישור</b>.',
+		cutError	: 'הגדרות האבטחה בדפדפן שלך לא מאפשרות לעורך לבצע פעולות גזירה אוטומטיות. יש להשתמש במקלדת לשם כך (Ctrl/Cmd+X).',
+		copyError	: 'הגדרות האבטחה בדפדפן שלך לא מאפשרות לעורך לבצע פעולות העתקה אוטומטיות. יש להשתמש במקלדת לשם כך (Ctrl/Cmd+C).',
+		pasteMsg	: 'נא להדביק בתוך הקופסה באמצעות (<b>Ctrl/Cmd+V</b>) וללחוץ על <b>אישור</b>.',
 		securityMsg	: 'עקב הגדרות אבטחה בדפדפן, לא ניתן לגשת אל לוח הגזירים (Clipboard) בצורה ישירה. נא להדביק שוב בחלון זה.',
-		pasteArea	: 'Paste Area' // MISSING
+		pasteArea	: 'איזור הדבקה'
 	},
 
 	pastefromword :
@@ -528,6 +554,7 @@ CKEDITOR.lang['he'] =
 	{
 		button			: 'תבניות',
 		title			: 'תביות תוכן',
+		options : 'אפשרויות התבניות',
 		insertOption	: 'החלפת תוכן ממשי',
 		selectPromptMsg	: 'יש לבחור תבנית לפתיחה בעורך.<br />התוכן המקורי ימחק:',
 		emptyListMsg	: '(לא הוגדרו תבניות)'
@@ -538,7 +565,7 @@ CKEDITOR.lang['he'] =
 	stylesCombo :
 	{
 		label		: 'סגנון',
-		panelTitle	: 'Formatting Styles', // MISSING
+		panelTitle	: 'סגנונות פורמט',
 		panelTitle1	: 'סגנונות בלוק',
 		panelTitle2	: 'סגנונות רצף',
 		panelTitle3	: 'סגנונות אובייקט'
@@ -578,6 +605,15 @@ CKEDITOR.lang['he'] =
 		remove				: 'הסרת מיכל (Div)'
   	},
 
+	iframe :
+	{
+		title		: 'מאפייני חלון פנימי (iframe)',
+		toolbar		: 'חלון פנימי (iframe)',
+		noUrl		: 'יש להכניס כתובת לחלון.',
+		scrolling	: 'אפשר פסי גלילה',
+		border		: 'הראה מסגרת לחלון'
+	},
+
 	font :
 	{
 		label		: 'גופן',
@@ -596,7 +632,7 @@ CKEDITOR.lang['he'] =
 	{
 		textColorTitle	: 'צבע טקסט',
 		bgColorTitle	: 'צבע רקע',
-		panelTitle		: 'Colors', // MISSING
+		panelTitle		: 'צבעים',
 		auto			: 'אוטומטי',
 		more			: 'צבעים נוספים...'
 	},
@@ -648,6 +684,7 @@ CKEDITOR.lang['he'] =
 	scayt :
 	{
 		title			: 'בדיקת איות בזמן כתיבה (SCAYT)',
+		opera_title		: 'לא זמין בדפדפן אופרה',
 		enable			: 'אפשר SCAYT',
 		disable			: 'בטל SCAYT',
 		about			: 'אודות SCAYT',
@@ -659,9 +696,23 @@ CKEDITOR.lang['he'] =
 		ignoreAll		: 'התעלמות מהכל',
 		addWord			: 'הוספת מילה',
 		emptyDic		: 'יש לבחור מילון.',
+
 		optionsTab		: 'אפשרויות',
+		allCaps			: 'התעלם ממילים שכל אותיותיהן גדולות',
+		ignoreDomainNames : 'התעלם משמות מתחם',
+		mixedCase		: 'התעלם ממילים עם אותיות גדולות וקטנות ביחד',
+		mixedWithDigits	: 'התעלם ממילים עם מספרים',
+
 		languagesTab	: 'שפות',
+
 		dictionariesTab	: 'מילון',
+		dic_field_name	: 'שם המילון',
+		dic_create		: 'יצירה',
+		dic_restore		: 'שחזור',
+		dic_delete		: 'מחיקה',
+		dic_rename		: 'שינוי שם',
+		dic_info		: 'בהתחלה מילון המשתמש מאוחסן בעוגיה, אך עוגיות מוגבלות במקום. כאשר המילון מגיע לגודל בו הוא אינו יכול להתאכסן בעוגיה, המילון צריך להתאכסן בשרתנו. לשם כך עליך לתת שם למילון. אם כבר יש לך מילון מאוחסן, יש להכניס את שמו וללחוץ על כפתור השחזור.',
+
 		aboutTab		: 'אודות'
 	},
 
@@ -669,6 +720,8 @@ CKEDITOR.lang['he'] =
 	{
 		title		: 'אודות CKEditor',
 		dlgTitle	: 'אודות CKEditor',
+		help	: 'היכנסו ל$1 לעזרה.',
+		userGuide : 'מדריך המשתמש של CKEditor',
 		moreInfo	: 'למידע נוסף בקרו באתרנו:',
 		copy		: 'Copyright &copy; $1. כל הזכויות שמורות.'
 	},
@@ -678,10 +731,11 @@ CKEDITOR.lang['he'] =
 
 	fakeobjects :
 	{
-		anchor	: 'עוגן',
-		flash	: 'סרטון פלאש',
-		div		: 'שבירת דף',
-		unknown	: 'אובייקט לא ידוע'
+		anchor		: 'עוגן',
+		flash		: 'סרטון פלאש',
+		iframe		: 'חלון פנימי (iframe)',
+		hiddenfield	: 'שדה חבוי',
+		unknown		: 'אובייקט לא ידוע'
 	},
 
 	resize : 'יש לגרור בכדי לשנות את הגודל',
@@ -689,11 +743,73 @@ CKEDITOR.lang['he'] =
 	colordialog :
 	{
 		title		: 'בחירת צבע',
+		options	:	'אפשרויות צבע',
 		highlight	: 'סימון',
 		selected	: 'בחירה',
 		clear		: 'ניקוי'
 	},
 
 	toolbarCollapse	: 'מזעור סרגל כלים',
-	toolbarExpand	: 'הרחבת סרגל כלים'
+	toolbarExpand	: 'הרחבת סרגל כלים',
+
+	toolbarGroups :
+	{
+		document : 'מסמך',
+		clipboard : 'לוח הגזירים (Clipboard)/צעד אחרון',
+		editing : 'עריכה',
+		forms : 'טפסים',
+		basicstyles : 'עיצוב בסיסי',
+		paragraph : 'פסקה',
+		links : 'קישורים',
+		insert : 'הכנסה',
+		styles : 'עיצוב',
+		colors : 'צבעים',
+		tools : 'כלים'
+	},
+
+	bidi :
+	{
+		ltr : 'כיוון טקסט משמאל לימין (LTR)',
+		rtl : 'כיוון טקסט מימין לשמאל (RTL)'
+	},
+
+	docprops :
+	{
+		label : 'מאפייני מסמך',
+		title : 'מאפייני מסמך',
+		design : 'עיצוב',
+		meta : 'תגי Meta',
+		chooseColor : 'בחירה',
+		other : 'אחר...',
+		docTitle :	'כותרת עמוד',
+		charset : 	'קידוד תווים',
+		charsetOther : 'קידוד תווים אחר',
+		charsetASCII : 'ASCII',
+		charsetCE : 'מרכז אירופאי',
+		charsetCT : 'סיני מסורתי (Big5)',
+		charsetCR : 'קירילי',
+		charsetGR : 'יווני',
+		charsetJP : 'יפני',
+		charsetKR : 'קוריאני',
+		charsetTR : 'טורקי',
+		charsetUN : 'יוניקוד (UTF-8)',
+		charsetWE : 'מערב אירופאי',
+		docType : 'כותר סוג מסמך',
+		docTypeOther : 'כותר סוג מסמך אחר',
+		xhtmlDec : 'כלול הכרזות XHTML',
+		bgColor : 'צבע רקע',
+		bgImage : 'כתובת של תמונת רקע',
+		bgFixed : 'רקע לא נגלל (צמוד)',
+		txtColor : 'צבע טקסט',
+		margin : 'מרווחי עמוד',
+		marginTop : 'עליון',
+		marginLeft : 'שמאלי',
+		marginRight : 'ימני',
+		marginBottom : 'תחתון',
+		metaKeywords : 'מילות מפתח של המסמך (מופרדות בפסיק)',
+		metaDescription : 'תיאור המסמך',
+		metaAuthor : 'מחבר/ת',
+		metaCopyright : 'זכויות יוצרים',
+		previewHtml : '<p>זהו <strong>טקסט הדגמה</strong>. את/ה משתמש/ת ב<a href="javascript:void(0)">CKEditor</a>.</p>'
+	}
 };
