@@ -1,5 +1,5 @@
 ﻿/*
-Copyright (c) 2003-2011, CKSource - Frederico Knabben. All rights reserved.
+Copyright (c) 2003-2012, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.html or http://ckeditor.com/license
 */
 
@@ -14,7 +14,7 @@ For licensing, see LICENSE.html or http://ckeditor.com/license
 */
 
 /**
- * Constains the dictionary of language entries.
+ * Contains the dictionary of language entries.
  * @namespace
  */
 CKEDITOR.lang['pt'] =
@@ -34,8 +34,8 @@ CKEDITOR.lang['pt'] =
 	editorTitle : 'Rich text editor, %1, press ALT 0 for help.', // MISSING
 
 	// ARIA descriptions.
-	toolbars	: 'Editor toolbars', // MISSING
-	editor		: 'Rich Text Editor', // MISSING
+	toolbars	: 'Editor de barras de ferramentas',
+	editor		: 'Editor de texto enriquecido',
 
 	// Toolbar buttons without dialogs.
 	source			: 'Fonte',
@@ -56,7 +56,7 @@ CKEDITOR.lang['pt'] =
 	superscript		: 'Inferior à Linha',
 	horizontalrule	: 'Inserir Linha Horizontal',
 	pagebreak		: 'Inserir Quebra de Página',
-	pagebreakAlt		: 'Page Break', // MISSING
+	pagebreakAlt		: 'Quebra de página',
 	unlink			: 'Eliminar Hiperligação',
 	undo			: 'Anular',
 	redo			: 'Repetir',
@@ -93,22 +93,22 @@ CKEDITOR.lang['pt'] =
 		cssStyle		: 'Estilo',
 		ok				: 'OK',
 		cancel			: 'Cancelar',
-		close			: 'Close', // MISSING
-		preview			: 'Preview', // MISSING
-		generalTab		: 'General', // MISSING
+		close			: 'Fechar',
+		preview			: 'Pré-visualização',
+		generalTab		: 'Geral',
 		advancedTab		: 'Avançado',
 		validateNumberFailed : 'This value is not a number.', // MISSING
 		confirmNewPage	: 'Any unsaved changes to this content will be lost. Are you sure you want to load new page?', // MISSING
 		confirmCancel	: 'Some of the options have been changed. Are you sure to close the dialog?', // MISSING
-		options			: 'Options', // MISSING
-		target			: 'Target', // MISSING
-		targetNew		: 'New Window (_blank)', // MISSING
-		targetTop		: 'Topmost Window (_top)', // MISSING
-		targetSelf		: 'Same Window (_self)', // MISSING
+		options			: 'Opções',
+		target			: 'Alvo',
+		targetNew		: 'Nova Janela (_blank)',
+		targetTop		: 'Janela superior (_top)',
+		targetSelf		: 'Mesma janela (_self)',
 		targetParent	: 'Parent Window (_parent)', // MISSING
 		langDirLTR		: 'Left to Right (LTR)', // MISSING
-		langDirRTL		: 'Right to Left (RTL)', // MISSING
-		styles			: 'Style', // MISSING
+		langDirRTL		: 'Direita para Esquerda (RTL)',
+		styles			: 'Estilo',
 		cssClasses		: 'Stylesheet Classes', // MISSING
 		width			: 'Largura',
 		height			: 'Altura',
@@ -121,6 +121,10 @@ CKEDITOR.lang['pt'] =
 		alignBottom		: 'Fundo',
 		invalidHeight	: 'Height must be a number.', // MISSING
 		invalidWidth	: 'Width must be a number.', // MISSING
+		invalidCssLength	: 'Value specified for the "%1" field must be a positive number with or without a valid CSS measurement unit (px, %, in, cm, mm, em, ex, pt, or pc).', // MISSING
+		invalidHtmlLength	: 'Value specified for the "%1" field must be a positive number with or without a valid HTML measurement unit (px or %).', // MISSING
+		invalidInlineStyle	: 'Value specified for the inline style must consist of one or more tuples with the format of "name : value", separated by semi-colons.', // MISSING
+		cssLengthTooltip	: 'Enter a number for a value in pixels or a number with a valid CSS unit (px, %, in, cm, mm, em, ex, pt, or pc).', // MISSING
 
 		// Put the voice-only part of the label in the span.
 		unavailable		: '%1<span class="cke_accessibility">, unavailable</span>' // MISSING
@@ -128,7 +132,7 @@ CKEDITOR.lang['pt'] =
 
 	contextmenu :
 	{
-		options : 'Context Menu Options' // MISSING
+		options : 'Menu de opções de contexto'
 	},
 
 	// Special char dialog.
@@ -151,7 +155,7 @@ CKEDITOR.lang['pt'] =
 		upload		: 'Carregar',
 		advanced	: 'Avançado',
 		type		: 'Tipo de Hiperligação',
-		toUrl		: 'URL', // MISSING
+		toUrl		: 'URL',
 		toAnchor	: 'Referência a esta página',
 		toEmail		: 'E-Mail',
 		targetFrame		: '<Frame>',
@@ -159,7 +163,7 @@ CKEDITOR.lang['pt'] =
 		targetFrameName	: 'Nome do Frame Destino',
 		targetPopupName	: 'Nome da Janela de Popup',
 		popupFeatures	: 'Características de Janela de Popup',
-		popupResizable	: 'Resizable', // MISSING
+		popupResizable	: 'Redimensionável',
 		popupStatusBar	: 'Barra de Estado',
 		popupLocationBar: 'Barra de localização',
 		popupToolbar	: 'Barra de Ferramentas',
@@ -169,7 +173,7 @@ CKEDITOR.lang['pt'] =
 		popupDependent	: 'Dependente (Netscape)',
 		popupLeft		: 'Posição Esquerda',
 		popupTop		: 'Posição Direita',
-		id				: 'Id', // MISSING
+		id				: 'ID',
 		langDir			: 'Orientação de idioma',
 		langDirLTR		: 'Esquerda à Direita (LTR)',
 		langDirRTL		: 'Direita a Esquerda (RTL)',
@@ -182,7 +186,7 @@ CKEDITOR.lang['pt'] =
 		cssClasses		: 'Classes de Estilo de Folhas Classes',
 		charset			: 'Fonte de caracteres vinculado',
 		styles			: 'Estilo',
-		rel			: 'Relationship', // MISSING
+		rel			: 'Relação',
 		selectAnchor		: 'Seleccionar una referência',
 		anchorName		: 'Por Nome de Referência',
 		anchorId			: 'Por ID de elemento',
@@ -201,7 +205,8 @@ CKEDITOR.lang['pt'] =
 		menu		: 'Propriedades da Âncora',
 		title		: 'Propriedades da Âncora',
 		name		: 'Nome da Âncora',
-		errorName	: 'Por favor, introduza o nome da âncora'
+		errorName	: 'Por favor, introduza o nome da âncora',
+		remove		: 'Remove Anchor' // MISSING
 	},
 
 	// List style dialog
@@ -209,15 +214,15 @@ CKEDITOR.lang['pt'] =
 	{
 		numberedTitle		: 'Numbered List Properties', // MISSING
 		bulletedTitle		: 'Bulleted List Properties', // MISSING
-		type				: 'Type', // MISSING
-		start				: 'Start', // MISSING
+		type				: 'Tipo',
+		start				: 'Iniciar',
 		validateStartNumber				:'List start number must be a whole number.', // MISSING
-		circle				: 'Circle', // MISSING
-		disc				: 'Disc', // MISSING
-		square				: 'Square', // MISSING
-		none				: 'None', // MISSING
-		notset				: '<not set>', // MISSING
-		armenian			: 'Armenian numbering', // MISSING
+		circle				: 'Círculo',
+		disc				: 'Disco',
+		square				: 'Quadrado',
+		none				: 'Nenhum',
+		notset				: '<not set>',
+		armenian			: 'Numeração armênia',
 		georgian			: 'Georgian numbering (an, ban, gan, etc.)', // MISSING
 		lowerRoman			: 'Lower Roman (i, ii, iii, iv, v, etc.)', // MISSING
 		upperRoman			: 'Upper Roman (I, II, III, IV, V, etc.)', // MISSING
@@ -237,6 +242,7 @@ CKEDITOR.lang['pt'] =
 		findWhat			: 'Texto a Procurar:',
 		replaceWith			: 'Substituir por:',
 		notFoundMsg			: 'O texto especificado não foi encontrado.',
+		findOptions			: 'Find Options', // MISSING
 		matchCase			: 'Maiúsculas/Minúsculas',
 		matchWord			: 'Coincidir com toda a palavra',
 		matchCyclic			: 'Match cyclic', // MISSING
@@ -271,8 +277,8 @@ CKEDITOR.lang['pt'] =
 		invalidBorder	: 'Border size must be a number.', // MISSING
 		invalidWidth	: 'Table width must be a number.', // MISSING
 		invalidHeight	: 'Table height must be a number.', // MISSING
-		invalidCellSpacing	: 'Cell spacing must be a number.', // MISSING
-		invalidCellPadding	: 'Cell padding must be a number.', // MISSING
+		invalidCellSpacing	: 'Cell spacing must be a positive number.', // MISSING
+		invalidCellPadding	: 'Cell padding must be a positive number.', // MISSING
 
 		cell :
 		{
@@ -413,7 +419,6 @@ CKEDITOR.lang['pt'] =
 		upload		: 'Carregar',
 		alt			: 'Texto Alternativo',
 		lockRatio	: 'Proporcional',
-		unlockRatio	: 'Unlock Ratio', // MISSING
 		resetSize	: 'Tamanho Original',
 		border		: 'Limite',
 		hSpace		: 'Esp.Horiz',
@@ -519,7 +524,7 @@ CKEDITOR.lang['pt'] =
 		block	: 'Justificado'
 	},
 
-	blockquote : 'Block Quote', // MISSING
+	blockquote : 'Bloco de citação',
 
 	clipboard :
 	{
@@ -555,7 +560,7 @@ CKEDITOR.lang['pt'] =
 		emptyListMsg	: '(Sem modelos definidos)'
 	},
 
-	showBlocks : 'Show Blocks', // MISSING
+	showBlocks : 'Exibir blocos',
 
 	stylesCombo :
 	{
@@ -721,8 +726,8 @@ CKEDITOR.lang['pt'] =
 		copy		: 'Copyright &copy; $1. All rights reserved.' // MISSING
 	},
 
-	maximize : 'Maximize', // MISSING
-	minimize : 'Minimize', // MISSING
+	maximize : 'Maximizar',
+	minimize : 'Minimizar',
 
 	fakeobjects :
 	{
@@ -733,7 +738,7 @@ CKEDITOR.lang['pt'] =
 		unknown		: 'Unknown Object' // MISSING
 	},
 
-	resize : 'Drag to resize', // MISSING
+	resize : 'Arraste para redimensionar',
 
 	colordialog :
 	{
@@ -744,8 +749,8 @@ CKEDITOR.lang['pt'] =
 		clear		: 'Clear' // MISSING
 	},
 
-	toolbarCollapse	: 'Collapse Toolbar', // MISSING
-	toolbarExpand	: 'Expand Toolbar', // MISSING
+	toolbarCollapse	: 'Colapsar Barra',
+	toolbarExpand	: 'Expandir Barra',
 
 	toolbarGroups :
 	{
@@ -770,15 +775,15 @@ CKEDITOR.lang['pt'] =
 
 	docprops :
 	{
-		label : 'Document Properties', // MISSING
-		title : 'Document Properties', // MISSING
+		label : 'Propriedades do Documento',
+		title : 'Propriedades do Documento',
 		design : 'Design', // MISSING
-		meta : 'Meta Tags', // MISSING
+		meta : 'Meta Data',
 		chooseColor : 'Choose', // MISSING
-		other : 'Other...', // MISSING
-		docTitle :	'Page Title', // MISSING
-		charset : 	'Character Set Encoding', // MISSING
-		charsetOther : 'Other Character Set Encoding', // MISSING
+		other : '<outro>',
+		docTitle :	'Título da Página',
+		charset : 	'Codificação de Caracteres',
+		charsetOther : 'Outra Codificação de Caracteres',
 		charsetASCII : 'ASCII', // MISSING
 		charsetCE : 'Central European', // MISSING
 		charsetCT : 'Chinese Traditional (Big5)', // MISSING
@@ -789,22 +794,22 @@ CKEDITOR.lang['pt'] =
 		charsetTR : 'Turkish', // MISSING
 		charsetUN : 'Unicode (UTF-8)', // MISSING
 		charsetWE : 'Western European', // MISSING
-		docType : 'Document Type Heading', // MISSING
-		docTypeOther : 'Other Document Type Heading', // MISSING
-		xhtmlDec : 'Include XHTML Declarations', // MISSING
-		bgColor : 'Background Color', // MISSING
-		bgImage : 'Background Image URL', // MISSING
-		bgFixed : 'Non-scrolling (Fixed) Background', // MISSING
-		txtColor : 'Text Color', // MISSING
-		margin : 'Page Margins', // MISSING
-		marginTop : 'Top', // MISSING
-		marginLeft : 'Left', // MISSING
-		marginRight : 'Right', // MISSING
-		marginBottom : 'Bottom', // MISSING
-		metaKeywords : 'Document Indexing Keywords (comma separated)', // MISSING
-		metaDescription : 'Document Description', // MISSING
-		metaAuthor : 'Author', // MISSING
-		metaCopyright : 'Copyright', // MISSING
+		docType : 'Tipo de Cabeçalho do Documento',
+		docTypeOther : 'Outro Tipo de Cabeçalho do Documento',
+		xhtmlDec : 'Incluir Declarações XHTML',
+		bgColor : 'Cor de Fundo',
+		bgImage : 'Caminho para a Imagem de Fundo',
+		bgFixed : 'Fundo Fixo',
+		txtColor : 'Cor do Texto',
+		margin : 'Margem das Páginas',
+		marginTop : 'Topo',
+		marginLeft : 'Esquerda',
+		marginRight : 'Direita',
+		marginBottom : 'Fundo',
+		metaKeywords : 'Palavras de Indexação do Documento (separadas por virgula)',
+		metaDescription : 'Descrição do Documento',
+		metaAuthor : 'Autor',
+		metaCopyright : 'Direitos de Autor',
 		previewHtml : '<p>This is some <strong>sample text</strong>. You are using <a href="javascript:void(0)">CKEditor</a>.</p>' // MISSING
 	}
 };
